==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/es-VE/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Un usuario ha cancelado una solicitud de articulo en el sitio web',
    'a_user_requested' => 'Un usuario ha solicitado un artículo en el sitio web',
    'accessory_name' => 'Nombre del Accesorio:',
    'additional_notes' => 'Notas Adicionales:',
    'admin_has_created' => 'Un administrador ha creado una cuenta para ti en el sitio web de :web.',
    'asset' => 'Activo:',
    'asset_name' => 'Nombre de Activo:',
    'asset_requested' => 'Activo solicitado',
    'asset_tag' => 'Etiqueta de Activo:',
    'assigned_to' => 'Asignado A',
    'best_regards' => 'Atentamente,',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Fecha de Entrada:',
    'checkout_date' => 'Fecha de Salida:',
    'click_to_confirm' => 'Por favor, pulsa en el siguiente enlace para verificar tu cuenta de :web:',
    'click_on_the_link_accessory' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el accesorio.',
    'click_on_the_link_asset' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el activo.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Cantidad actual',
    'Days' => 'Días',
    'days' => 'Días',
    'expecting_checkin_date' => 'Fecha de Entrega Prevista:',
    'expires' => 'Vence',
    'Expiring_Assets_Report' => 'Reportes de Activos que Vencen.',
    'Expiring_Licenses_Report' => 'Reportes de Licencias que Vencen.',
    'hello' => 'Hola',
    'hi' => 'Hola',
    'i_have_read' => 'He leído y acepto los términos de uso, y he recibido éste artículo.',
    'item' => 'Artículo:',
    'Item_Request_Canceled' => 'Solicitud de Artículo Cancelada',
    'Item_Requested' => 'Artículo Solicitado',
    'link_to_update_password' => 'Haz click en el siguiente link para actualizar la contraseña de tu :web:',
    'login_first_admin' => 'Inicia sesión en tu nueva instalación de Snipe-IT usando las credenciales abajo:',
    'login' => 'Iniciar Sesión:',
    'Low_Inventory_Report' => 'Reporte de inventario bajo',
    'min_QTY' => 'Cantidad mínima',
    'name' => 'Nombre',
    'new_item_checked' => 'Un nuevo artículo se ha retirado bajo tu nombre, los detalles están a continuación.',
    'password' => 'Contraseña:',
    'password_reset' => 'Restablecer Contraseña',

    'read_the_terms' => 'Por favor lee los términos de uso a continuación.',
    'read_the_terms_and_click' => 'Por favor lea los términos de uso a continuación y haga clic en el enlace en la parte inferior para confirmar que has leído y aceptas los términos de uso y has recibido el activo.',
    'requested' => 'Solicitado:',
    'reset_link' => 'Tu Enlace de Reestablecimiento de Contraseña',
    'reset_password' => 'Haz click aquí para reestablecer tu contraseña:',
    'serial' => 'Número de serie',
    'supplier' => 'Proveedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de prueba de Snipe-IT',
    'test_mail_text' => 'Esto es una prueba desde el sistema de gestión de activos de Snipe-IT. Si tienes esto, correo está funcionando :)',
    'the_following_item' => 'El siguiente artículo ha sido devuelto: ',
    'low_inventory_alert' => 'Hay :count elemento que está por debajo del inventario mínimo o que pronto estará debajo.|Hay :count elementos que están por debajo del inventario mínimo o que pronto serán bajos.',
    'assets_warrantee_alert' => 'Hay :count licencia que expira en los próximos :threshold días. | Hay :count licencias que expiran en los próximos :threshold días.',
    'license_expiring_alert' => 'Hay :count licencia que expira en los próximos :threshold días. | Hay :count licencias que expiran en los próximos :threshold días.',
    'to_reset' => 'Para restaurar tu contraseña de :web, rellena este formulario:',
    'type' => 'Tipo',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Usuario',
    'username' => 'Nombre de usuario',
    'welcome' => 'Bienvenido :name',
    'welcome_to' => '¡Bienvenido a :web!',
    'your_credentials' => 'Tus credenciales de Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accesorio devuelto',
    'Asset_Checkin_Notification' => 'Activo devuelto',
    'License_Checkin_Notification' => 'Licencia devuelta',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Recordatorio: :name se acerca la fecha de devolución',
    'Expected_Checkin_Date' => 'Un activo asignado a ti debe ser devuelto en :date',
    'your_assets' => 'Ver tus activos'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/es-VE/mail.php <==
<?php

return [
    'a_user_canceled' => 'Un usuario ha cancelado una solicitud de articulo en el sitio web',
    'a_user_requested' => 'Un usuario ha solicitado un artículo en el sitio web',
    'accessory_name' => 'Nombre del Accesorio:',
    'additional_notes' => 'Notas Adicionales:',
    'admin_has_created' => 'Un administrador ha creado una cuenta para ti en el sitio web de :web.',
    'asset' => 'Activo:',
    'asset_name' => 'Nombre de Activo:',
    'asset_requested' => 'Activo solicitado',
    'asset_tag' => 'Etiqueta de activo',
    'assigned_to' => 'Asignado A',
    'best_regards' => 'Atentamente,',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Fecha de Entrada:',
    'checkout_date' => 'Fecha de Salida:',
    'click_to_confirm' => 'Por favor, pulsa en el siguiente enlace para verificar tu cuenta de :web:',
    'click_on_the_link_accessory' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el accesorio.',
    'click_on_the_link_asset' => 'Haga clic en el enlace en la parte inferior para confirmar que ha recibido el activo.',
    'Confirm_Asset_Checkin' => 'Confirmación de devolución de activo',
    'Confirm_Accessory_Checkin' => 'Confirmación de devolución de accesorio',
    'Confirm_accessory_delivery' => 'Confirmación de entrega del accesorio',
    'Confirm_license_delivery' => 'Confirmación de entrega de la licencia',
    'Confirm_asset_delivery' => 'Confirmación de entrega del activo',
    'Confirm_consumable_delivery' => 'Confirmación de entrega del consumible',
    'current_QTY' => 'Cantidad actual',
    'Days' => 'Días',
    'days' => 'Días',
    'expecting_checkin_date' => 'Fecha de Entrega Prevista:',
    'expires' => 'Vence',
    'Expiring_Assets_Report' => 'Reportes de Activos que Vencen.',
    'Expiring_Licenses_Report' => 'Reportes de Licencias que Vencen.',
    'hello' => 'Hola',
    'hi' => 'Hola',
    'i_have_read' => 'He leído y acepto los términos de uso, y he recibido éste artículo.',
    'item' => 'Artículo:',
    'Item_Request_Canceled' => 'Solicitud de Artículo Cancelada',
    'Item_Requested' => 'Artículo Solicitado',
    'link_to_update_password' => 'Haz click en el siguiente link para actualizar la contraseña de tu :web:',
    'login_first_admin' => 'Inicia sesión en tu nueva instalación de Snipe-IT usando las credenciales abajo:',
    'login' => 'Iniciar Sesión:',
    'Low_Inventory_Report' => 'Reporte de inventario bajo',
    'min_QTY' => 'Cantidad mínima',
    'name' => 'Nombre',
    'new_item_checked' => 'Un nuevo artículo se ha retirado bajo tu nombre, los detalles están a continuación.',
    'password' => 'Contraseña:',
    'password_reset' => 'Restablecer Contraseña',

    'read_the_terms' => 'Por favor lee los términos de uso a continuación.',
    'read_the_terms_and_click' => 'Por favor lea los términos de uso a continuación y haga clic en el enlace en la parte inferior para confirmar que has leído y aceptas los términos de uso y has recibido el activo.',
    'requested' => 'Solicitado:',
    'reset_link' => 'Tu Enlace de Reestablecimiento de Contraseña',
    'reset_password' => 'Haz click aquí para reestablecer tu contraseña:',
    'serial' => 'Número de serie',
    'supplier' => 'Proveedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de prueba de Snipe-IT',
    'test_mail_text' => 'Esto es una prueba desde el sistema de gestión de activos de Snipe-IT. Si tienes esto, correo está funcionando :)',
    'the_following_item' => 'El siguiente artículo ha sido devuelto: ',
    'low_inventory_alert' => 'Hay :count elemento que está por debajo del inventario mínimo o que pronto estará debajo.|Hay :count elementos que están por debajo del inventario mínimo o que pronto serán bajos.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Hay :count licencia que expira en los próximos :threshold días. | Hay :count licencias que expiran en los próximos :threshold días.',
    'to_reset' => 'Para restaurar tu contraseña de :web, rellena este formulario:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Hay :count activo que se está preparando para auditoría dentro de :threshold days.|Hay :count activos que se están preparando para auditoría en :threshold days.',
    'user' => 'Usuario',
    'username' => 'Nombre de usuario',
    'welcome' => 'Bienvenido :name',
    'welcome_to' => '¡Bienvenido a :web!',
    'your_credentials' => 'Tus credenciales de Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accesorio devuelto',
    'Asset_Checkin_Notification' => 'Activo devuelto',
    'License_Checkin_Notification' => 'Licencia devuelta',
    'Expected_Checkin_Report' => 'Informe de devolución de activo esperado',
    'Expected_Checkin_Notification' => 'Recordatorio: :name se acerca la fecha de devolución',
    'Expected_Checkin_Date' => 'Un activo asignado a ti debe ser devuelto en :date',
    'your_assets' => 'Ver tus activos',
];
